fake

package
v0.0.0-...-e030e20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

Package fake has the automatically generated clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FakeComputeDomainCliques

type FakeComputeDomainCliques struct {
	Fake *FakeResourceV1beta1
	// contains filtered or unexported fields
}

FakeComputeDomainCliques implements ComputeDomainCliqueInterface

func (*FakeComputeDomainCliques) Create

func (c *FakeComputeDomainCliques) Create(ctx context.Context, computeDomainClique *v1beta1.ComputeDomainClique, opts v1.CreateOptions) (result *v1beta1.ComputeDomainClique, err error)

Create takes the representation of a computeDomainClique and creates it. Returns the server's representation of the computeDomainClique, and an error, if there is any.

func (*FakeComputeDomainCliques) Delete

Delete takes name of the computeDomainClique and deletes it. Returns an error if one occurs.

func (*FakeComputeDomainCliques) DeleteCollection

func (c *FakeComputeDomainCliques) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeComputeDomainCliques) Get

func (c *FakeComputeDomainCliques) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ComputeDomainClique, err error)

Get takes name of the computeDomainClique, and returns the corresponding computeDomainClique object, and an error if there is any.

func (*FakeComputeDomainCliques) List

List takes label and field selectors, and returns the list of ComputeDomainCliques that match those selectors.

func (*FakeComputeDomainCliques) Patch

func (c *FakeComputeDomainCliques) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ComputeDomainClique, err error)

Patch applies the patch and returns the patched computeDomainClique.

func (*FakeComputeDomainCliques) Update

func (c *FakeComputeDomainCliques) Update(ctx context.Context, computeDomainClique *v1beta1.ComputeDomainClique, opts v1.UpdateOptions) (result *v1beta1.ComputeDomainClique, err error)

Update takes the representation of a computeDomainClique and updates it. Returns the server's representation of the computeDomainClique, and an error, if there is any.

func (*FakeComputeDomainCliques) Watch

Watch returns a watch.Interface that watches the requested computeDomainCliques.

type FakeComputeDomains

type FakeComputeDomains struct {
	Fake *FakeResourceV1beta1
	// contains filtered or unexported fields
}

FakeComputeDomains implements ComputeDomainInterface

func (*FakeComputeDomains) Create

func (c *FakeComputeDomains) Create(ctx context.Context, computeDomain *v1beta1.ComputeDomain, opts v1.CreateOptions) (result *v1beta1.ComputeDomain, err error)

Create takes the representation of a computeDomain and creates it. Returns the server's representation of the computeDomain, and an error, if there is any.

func (*FakeComputeDomains) Delete

func (c *FakeComputeDomains) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error

Delete takes name of the computeDomain and deletes it. Returns an error if one occurs.

func (*FakeComputeDomains) DeleteCollection

func (c *FakeComputeDomains) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error

DeleteCollection deletes a collection of objects.

func (*FakeComputeDomains) Get

func (c *FakeComputeDomains) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ComputeDomain, err error)

Get takes name of the computeDomain, and returns the corresponding computeDomain object, and an error if there is any.

func (*FakeComputeDomains) List

func (c *FakeComputeDomains) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ComputeDomainList, err error)

List takes label and field selectors, and returns the list of ComputeDomains that match those selectors.

func (*FakeComputeDomains) Patch

func (c *FakeComputeDomains) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ComputeDomain, err error)

Patch applies the patch and returns the patched computeDomain.

func (*FakeComputeDomains) Update

func (c *FakeComputeDomains) Update(ctx context.Context, computeDomain *v1beta1.ComputeDomain, opts v1.UpdateOptions) (result *v1beta1.ComputeDomain, err error)

Update takes the representation of a computeDomain and updates it. Returns the server's representation of the computeDomain, and an error, if there is any.

func (*FakeComputeDomains) UpdateStatus

func (c *FakeComputeDomains) UpdateStatus(ctx context.Context, computeDomain *v1beta1.ComputeDomain, opts v1.UpdateOptions) (*v1beta1.ComputeDomain, error)

UpdateStatus was generated because the type contains a Status member. Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().

func (*FakeComputeDomains) Watch

Watch returns a watch.Interface that watches the requested computeDomains.

type FakeResourceV1beta1

type FakeResourceV1beta1 struct {
	*testing.Fake
}

func (*FakeResourceV1beta1) ComputeDomainCliques

func (c *FakeResourceV1beta1) ComputeDomainCliques(namespace string) v1beta1.ComputeDomainCliqueInterface

func (*FakeResourceV1beta1) ComputeDomains

func (c *FakeResourceV1beta1) ComputeDomains(namespace string) v1beta1.ComputeDomainInterface

func (*FakeResourceV1beta1) RESTClient

func (c *FakeResourceV1beta1) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

Jump to